import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

class AreaDesenho extends JPanel implements MouseMotionListener
{
    Aplicacao aplic; // ref. para aplicao principal
    Point pontos[] = new Point[100];
    int total;
    int sel;   // bola selecionada ou -1 se nenhuma

    public AreaDesenho(Aplicacao aplic,int w,int h)
    {
        super();
        this.aplic = aplic;
        sel = -1;
        setPreferredSize(new Dimension(w,h));
        addMouseListener(
          new MouseAdapter()
          {
            public void mousePressed(MouseEvent e)
            {
                novoPonto(e.getX(),e.getY());
            }
          });
        // Para tratar mouse drag (arrasto)
        addMouseMotionListener(this);
        total = 0;
    }

    public void paintComponent(Graphics g)
    {
        super.paintComponent(g); // pinta o fundo       
        g.setColor(Color.red);
        for(int i=0;i<total;++i)
        {
           g.setColor(Color.black);
           // Desenha linha ao ponto anterior
           if(i>0) g.drawLine(pontos[i-1].x,pontos[i-1].y,
                                pontos[i].x,pontos[i].y);
           // Se for o selecionado, desenha bola vermelha
           if(i==sel) g.setColor(Color.red);
           // ... seno, azul
            else g.setColor(Color.blue);
           g.drawOval(pontos[i].x-5,pontos[i].y-5,10,10);       
        }
    }

    public void novoPonto(int x, int y)
    {
        int c;
        // Verifica se clicou sobre um ponto existente
        for(c=0;c<total;++c)
        {
            if(pontos[c].x >= x-5 && pontos[c].x <= x+5 &&
               pontos[c].y >= y-5 && pontos[c].y <= y+5)
            {
                // Sim, seta como selecionado,
                // redesenha a tela e retorna
                sel = c;
                repaint();
                return;
            }
        }
        // No achou, verifica se chegou ao limite
        if(total==100) return;
        // No, adiciona novo ponto e redesenha
        pontos[total] = new Point(x,y);
        sel = -1;
        total++;
        aplic.atualizaCont(total);
        repaint();
    }

    // Chamada quando o mouse for arrastado e o boto
    // estiver pressionado
    public void mouseDragged(MouseEvent e)
    {
        int x2,y2;
        Dimension tam = new Dimension();
        // Se no houver ningum selecionado, retorna
        if(sel==-1) return;
        // Obtm as coords atuais do mouse
        x2 = e.getX(); y2 = e.getY();
        // Compara com as dimenses da janela:
        // Se for superior em x/y ou menor que 0,
        // ajusta para o mximo/mnimo
        getSize(tam);
        if(x2<0) x2=0;
        if(x2>tam.width) x2 = (int) tam.width;
        if(y2<0) y2=0;
        if(y2>tam.height) y2 = (int) tam.height;
        // Atualiza a posio do ponto selecionado
        pontos[sel].x = x2;
        pontos[sel].y = y2;
        // Redesenha
        repaint();
    }

    // Chamada quando houver movimento do mouse,
    // no  necessria aqui
    public void mouseMoved(MouseEvent e) {}

}